===========
Experiments
===========

This folder contains all scripts which were used to obtain the results. All of the modules in this folder
represent `PyComex`_ ``Experiment`` modules. This means that it should be possible to execute any of the
scripts on their own - assuming the package has been previously installed correctly.

Upon executing one of the scripts a new artifacts folder will be created automatically. This
artifact folder contains the experiment progress log in the ``experiment_log.txt``, all of the recorded
metrics etc. within the ``experiment_data.json`` file and all the created plots etc.

For more information visit the PyComex_ repository.

.. _PyComex: https://github.com/the16thpythonist/pycomex